==> ZenTaoALM.12.4.1.int.zbox_32.tar.gz: zbox/app/zentaoep/lib/spout/Common/Type.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPpxVHhG59xkxP6hJbmRpZdk0dugBvxJQedKw95ISV+E56P/pQkdJ8HbYjywxhkJnYUI2TRfQ
pHHyDyDLrfnxPBFQocKtQrBfwZ88XUdYeDQXmwnP7EDgv51BnpKuKHB3l7jfbTHvbtLJPoSv1cTt
Fz1ekMfRUiZVS9tFtE1uko0WJFxx97XW3pu43ycYbUhYulGbm4ilqjCAhutJinl+kRrQR9zcOpqr
9p5PCvSRIJaftKlzjFRd+Ir0l1oS6Y2IpXBsDNHcHsKdwcQ7dGWC7zLZa+nAp/zXNKksurwWdSEq
ZZ5JB2rAjrNrrRz+zZNGp23CUuuItAX5eV29BSY+APMBRhe3vH94AAEQnMF47zDBOHXwb1wVSjB8
2BO1Zmq6DXpbm57JhwNTe9Ud/8qiXu9tDPEa7dzRvWV/mpL4rvUVaS33lMqxays/o7F6uezpqi5a
83gB1iCpfeMGpJEP5hMAiO1KN3uWxO2YpUU+krDMrZhMxGV4cehapruwjAwFlSC5Gceq03N5Gk1E
Byz8ZKK4MKuGWExtEy9qNaCnk+F51Hebng2d13KBzVpX/utNKx+MpRlQ6axZ2JFiTcM0beAQIBSJ
T+SGwTSl1wSJFo/6bInf1Zy0B5yO7ZLWx3MsiB1HLL595QkJt9MWj9Mgbb+DZ9hNcY/rZMCEuC3/
6F2Y87eDaf5Q8zTy6iKY/W/LGNa0ZcRVm9GMd1iVoDO6kj/mB0uTiGWnW51124wCMbrZMZIL1DoF
TINm19xPY05OpzpVy6lm3V5Gi+u1pA8/Gb+2i3vfslAJ+l/w2a8Z1/lzYbtc/YbEFUriqRop1411
wrXB2azMWX6mlkeXbUXJP2p1YMvEpEPJer2+A67ZI1q3TF9u7iMpXjbb97PoW6hK2DbzkBQCWNHU
nvNnu65HI/7RVfROIENR2wPD1ojLbsl/nBtO3z1D8KIK+7KHnZ/n3/oichdrzg7h7ALMqXnN

==> ZenTaoALM.12.5.2.int.zbox_32.tar.gz: zbox/app/zentaoep/lib/spout/Common/Type.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPuURBvImOfJR+IwwjtIYSCOsktP/F+xrwHV7YIkI7jFy2CdRLhVN8i2728VEw4Hg25w5yFUl
CBM6Dw9FjRsm4lDPPS4WymBHIz2SnjUrA8wtnR8NdI93WP2MkdiXDWQ8uy7jpa2ccQhMFroo7Cyk
L+bpAfZOObHdZ5JH0KmkxH+YDVuFJNDoEwFV1xzK6vEsxaRrfyB45UJpUOgIK19m1Sr436oQ/1cF
OUNKuEb/xUWC9KGL6ZaONIc7mrx4XDas+fhVykYKQ5Uz3b89yMbDZQQmBq0KdkjZDp1VK9csdi++
kRLerFO2c0NkGdX2FIOtL8b+v4ArEp4clcHi/3R11P0Lof+SaIEk4u0MKYDjTFWQ+dGnBnvxiBqD
kCln376q5uhkb8yHvw0MqS6LjGHULVroc8paQRTcKYKeE0T0QIG7SJ2hdFzskgIF08BMBi3UCwpU
mv6nPfsjGQK766IGgVkETvA5Xow/Pk05+gAyhbTONWEoY2fWiyEec9HAnlM917QoBFzqT3tNXLe8
gHbp7S5pCo5wXSP2tPlEhBPsp9xEboLdWp2Nq8lfpZFGLJammzlAfG5Y1ShOpap7GJMJwuyr4Us2
gOfz1VOEk+WlJGnS8wCgsPwAVdFOl4VdAOkl3lhONhzogojwzupMtsapwmOQHT2QJGkSqPS+oaH+
5hocTS3oO/YV8iueotI5BCAWMP8Ol2ZzVUOvp2qYJ+56XH2bsv/yxYNF5Bc0WBz24aQy1mnR9b6c
ibE+2qOv8cbqT1PGsycsMh8SetxXAO9ThvRSlufYIDPFzaZ2KS49i+GdzVKLhSrEdvlEt/2s7NNS
HpgzXMjIoiX3OcRnOJMQBSpw/pCatPe5xV0tOvY78DvtDOQMgW5VkxSEmciOYU9QEel7C752+U/9
vfFnkT6tm7vJ0gpmt1PZLWB9juOEP/wxPj62wNjUQg4SKgBPS+CXLzA6e5/zuzIqg6ss9y0wFYAu
aCOwIi8MRmDaH3hfwd5fIBt+ClEh8kJEQ0==
